# dummy module for global variables.
# See http://docs.python.org/faq/programming#how-do-i-share-global-variables-across-modules

Log = None
plain = False
the_config = None
